==> api-0.0.7-sources.jar: threads/core/api/Thread.java <==
package threads.core.api;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.room.ColumnInfo;
import androidx.room.PrimaryKey;
import androidx.room.TypeConverters;

import java.util.Date;
import java.util.Objects;

import threads.core.Preferences;
import threads.core.THREADS;
import threads.ipfs.api.CID;
import threads.ipfs.api.PID;

import static androidx.core.util.Preconditions.checkNotNull;

@androidx.room.Entity
public class Thread extends Entity {

    @ColumnInfo(name = "thread")
    private final long thread;
    @NonNull
    @TypeConverters(Kind.class)
    @ColumnInfo(name = "kind")
    private final Kind kind;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "senderPid")
    private final PID senderPid;
    @NonNull
    @ColumnInfo(name = "senderKey")
    private final String senderKey;
    @NonNull
    @ColumnInfo(name = "sesKey")
    private final String sesKey;
    @ColumnInfo(name = "readOnly")
    private final boolean readOnly;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "date")
    private final Date date;
    @NonNull
    @ColumnInfo(name = "senderAlias")
    private String senderAlias;
    @PrimaryKey(autoGenerate = true)
    private long idx;
    @Nullable
    @ColumnInfo(name = "image")
    @TypeConverters(Converter.class)
    private CID image;
    @ColumnInfo(name = "markedFlag")
    private boolean markedFlag;
    @ColumnInfo(name = "unreadNotes")
    private int unreadNotes = 0;
    @Nullable
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "cid")
    private CID cid;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "expireDate")
    private Date expireDate;
    @NonNull
    @TypeConverters(ThreadStatus.class)
    @ColumnInfo(name = "status")
    private ThreadStatus status;
    @NonNull
    @TypeConverters(Members.class)
    @ColumnInfo(name = "members")
    private Members members = new Members();
    @NonNull
    @ColumnInfo(name = "mimeType")
    private String mimeType;

    Thread(@NonNull ThreadStatus status,
           @NonNull PID senderPid,
           @NonNull String senderAlias,
           @NonNull String senderKey,
           @NonNull String sesKey,
           @NonNull Kind kind,
           @NonNull Date date,
           long thread,
           boolean readOnly) {
        this.thread = thread;
        this.senderPid = senderPid;
        this.senderAlias = senderAlias;
        this.senderKey = senderKey;

        this.sesKey = sesKey;
        this.kind = kind;
        this.expireDate = THREADS.getOffsetYearDate(-20);
        this.status = status;
        this.readOnly = readOnly;
        this.markedFlag = false;
        this.date = date;
        this.mimeType = Preferences.PLAIN_MIME_TYPE;
    }

    public static Thread createThread(@NonNull ThreadStatus threadStatus,
                                      @NonNull PID senderPid,
                                      @NonNull String senderAlias,
                                      @NonNull String senderKey,
                                      @NonNull String sesKey,
                                      @NonNull Kind kind,
                                      @NonNull Date date,
                                      long thread,
                                      boolean readOnly) {
        checkNotNull(threadStatus);
        checkNotNull(senderPid);
        checkNotNull(senderAlias);
        checkNotNull(senderKey);
        checkNotNull(sesKey);
        checkNotNull(kind);
        checkNotNull(date);
        return new Thread(threadStatus,
                senderPid, senderAlias, senderKey,
                sesKey, kind, date, thread, readOnly);
    }

    public long getIdx() {
        return idx;
    }

    void setIdx(long idx) {
        this.idx = idx;
    }

    @NonNull
    public String getSenderBox() {
        return AddressType.getAddress(getSenderPid(), AddressType.INBOX);
    }

    @NonNull
    public String getSenderKey() {
        return senderKey;
    }

    @NonNull
    public String getMimeType() {
        return mimeType;
    }

    public void setMimeType(@NonNull String mimeType) {
        this.mimeType = mimeType;
    }

    @NonNull
    public PID getSenderPid() {
        return senderPid;
    }

    @NonNull
    public Date getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(@NonNull Date expireDate) {
        this.expireDate = expireDate;
    }

    @NonNull
    public ThreadStatus getStatus() {
        return status;
    }

    public void setStatus(@NonNull ThreadStatus status) {
        checkNotNull(status);
        this.status = status;
    }

    @NonNull
    public Kind getKind() {
        return kind;
    }

    @NonNull
    public Members getMembers() {
        return members;
    }

    public void setMembers(@NonNull Members members) {
        this.members = members;
    }

    public boolean addMember(@NonNull PID pid) {
        checkNotNull(pid);
        return this.members.add(pid);
    }

    public boolean removeMember(@NonNull PID pid) {
        checkNotNull(pid);
        return this.members.remove(pid);
    }

    public boolean sameThread(@NonNull Thread o) {
        checkNotNull(o);
        if (this == o) return true;
        return Objects.equals(cid, o.getCid()) &&
                Objects.equals(senderPid, o.getSenderPid()) &&
                Objects.equals(image, o.getImage()) &&
                Objects.equals(date, o.getDate());
    }

    public boolean sameContent(@NonNull Thread o) {
        checkNotNull(o);
        if (this == o) return true;
        return unreadNotes == o.getUnreadNotes() &&
                markedFlag == o.getMarkedFlag() &&
                status == o.getStatus() &&
                Objects.equals(cid, o.getCid()) &&
                Objects.equals(senderAlias, o.getSenderAlias()) &&
                Objects.equals(image, o.getImage()) &&
                Objects.equals(date, o.getDate());
    }

    @Nullable
    public CID getImage() {
        return image;
    }

    public void setImage(@Nullable CID image) {
        this.image = image;
    }

    public boolean areItemsTheSame(@NonNull Thread thread) {
        checkNotNull(thread);
        return idx == thread.getIdx();

    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Thread thread = (Thread) o;
        return getIdx() == thread.getIdx();
    }

    @Override
    public int hashCode() {

        return Objects.hash(getIdx());
    }

    @Nullable
    public CID getCid() {
        return cid;
    }

    void setCid(@Nullable CID cid) {
        this.cid = cid;
    }

    @NonNull
    public String getSenderAlias() {
        return senderAlias;
    }

    public void setSenderAlias(@NonNull String senderAlias) {
        checkNotNull(senderAlias);
        this.senderAlias = senderAlias;
    }

    public boolean getMarkedFlag() {
        return markedFlag;
    }

    public void setMarkedFlag(boolean markedFlag) {
        this.markedFlag = markedFlag;
    }

    public int getUnreadNotes() {
        return unreadNotes;
    }

    public void setUnreadNotes(int unreadNotes) {
        this.unreadNotes = unreadNotes;
    }

    public long getThread() {
        return thread;
    }

    @NonNull
    public String getSesKey() {
        return sesKey;
    }

    public void increaseUnreadMessagesNumber() {
        unreadNotes++;
    }

    @NonNull
    public Date getDate() {
        return date;
    }

    public boolean isReadOnly() {
        return readOnly;
    }

    public boolean isEncrypted() {
        return !sesKey.isEmpty();
    }

}

==> api-0.1.2-sources.jar: threads/core/api/Thread.java <==
package threads.core.api;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.room.ColumnInfo;
import androidx.room.PrimaryKey;
import androidx.room.TypeConverters;

import java.util.Date;
import java.util.Objects;

import threads.core.Preferences;
import threads.core.THREADS;
import threads.ipfs.api.CID;
import threads.ipfs.api.PID;

import static androidx.core.util.Preconditions.checkNotNull;

@androidx.room.Entity
public class Thread extends Entity {

    @ColumnInfo(name = "thread")
    private final long thread;
    @NonNull
    @TypeConverters(Kind.class)
    @ColumnInfo(name = "kind")
    private final Kind kind;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "senderPid")
    private final PID senderPid;
    @NonNull
    @ColumnInfo(name = "senderKey")
    private final String senderKey;
    @NonNull
    @ColumnInfo(name = "sesKey")
    private final String sesKey;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "date")
    private final Date date;
    @Deprecated
    @ColumnInfo(name = "readOnly")
    private boolean readOnly;
    @NonNull
    @ColumnInfo(name = "senderAlias")
    private String senderAlias;
    @PrimaryKey(autoGenerate = true)
    private long idx;
    @Nullable
    @ColumnInfo(name = "image")
    @TypeConverters(Converter.class)
    private CID image;
    @ColumnInfo(name = "markedFlag")
    private boolean markedFlag;
    @ColumnInfo(name = "unreadNotes")
    private int unreadNotes = 0;
    @Nullable
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "cid")
    private CID cid;
    @NonNull
    @TypeConverters(Converter.class)
    @ColumnInfo(name = "expireDate")
    private Date expireDate;
    @NonNull
    @TypeConverters(ThreadStatus.class)
    @ColumnInfo(name = "status")
    private ThreadStatus status;
    @NonNull
    @TypeConverters(Members.class)
    @ColumnInfo(name = "members")
    private Members members = new Members();
    @NonNull
    @ColumnInfo(name = "mimeType")
    private String mimeType;
    Thread(@NonNull ThreadStatus status,
           @NonNull PID senderPid,
           @NonNull String senderAlias,
           @NonNull String senderKey,
           @NonNull String sesKey,
           @NonNull Kind kind,
           @NonNull Date date,
           long thread) {
        this.thread = thread;
        this.senderPid = senderPid;
        this.senderAlias = senderAlias;
        this.senderKey = senderKey;

        this.sesKey = sesKey;
        this.kind = kind;
        this.expireDate = THREADS.getOffsetYearDate(-20);
        this.status = status;
        this.readOnly = false;
        this.markedFlag = false;
        this.date = date;
        this.mimeType = Preferences.PLAIN_MIME_TYPE;
    }

    public static Thread createThread(@NonNull ThreadStatus threadStatus,
                                      @NonNull PID senderPid,
                                      @NonNull String senderAlias,
                                      @NonNull String senderKey,
                                      @NonNull String sesKey,
                                      @NonNull Kind kind,
                                      @NonNull Date date,
                                      long thread) {
        checkNotNull(threadStatus);
        checkNotNull(senderPid);
        checkNotNull(senderAlias);
        checkNotNull(senderKey);
        checkNotNull(sesKey);
        checkNotNull(kind);
        checkNotNull(date);
        return new Thread(threadStatus,
                senderPid, senderAlias, senderKey,
                sesKey, kind, date, thread);
    }

    public long getIdx() {
        return idx;
    }

    void setIdx(long idx) {
        this.idx = idx;
    }

    @NonNull
    public String getSenderBox() {
        return AddressType.getAddress(getSenderPid(), AddressType.INBOX);
    }

    @NonNull
    public String getSenderKey() {
        return senderKey;
    }

    @NonNull
    public String getMimeType() {
        return mimeType;
    }

    public void setMimeType(@NonNull String mimeType) {
        this.mimeType = mimeType;
    }

    @NonNull
    public PID getSenderPid() {
        return senderPid;
    }

    @NonNull
    public Date getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(@NonNull Date expireDate) {
        this.expireDate = expireDate;
    }

    @NonNull
    public ThreadStatus getStatus() {
        return status;
    }

    public void setStatus(@NonNull ThreadStatus status) {
        checkNotNull(status);
        this.status = status;
    }

    @NonNull
    public Kind getKind() {
        return kind;
    }

    @NonNull
    public Members getMembers() {
        return members;
    }

    public void setMembers(@NonNull Members members) {
        this.members = members;
    }

    public boolean addMember(@NonNull PID pid) {
        checkNotNull(pid);
        return this.members.add(pid);
    }

    public boolean removeMember(@NonNull PID pid) {
        checkNotNull(pid);
        return this.members.remove(pid);
    }

    public boolean sameThread(@NonNull Thread o) {
        checkNotNull(o);
        if (this == o) return true;
        return Objects.equals(cid, o.getCid()) &&
                Objects.equals(senderPid, o.getSenderPid()) &&
                Objects.equals(image, o.getImage()) &&
                Objects.equals(date, o.getDate());
    }

    public boolean sameContent(@NonNull Thread o) {
        checkNotNull(o);
        if (this == o) return true;
        return unreadNotes == o.getUnreadNotes() &&
                markedFlag == o.getMarkedFlag() &&
                status == o.getStatus() &&
                Objects.equals(cid, o.getCid()) &&
                Objects.equals(senderAlias, o.getSenderAlias()) &&
                Objects.equals(image, o.getImage()) &&
                Objects.equals(date, o.getDate());
    }

    @Nullable
    public CID getImage() {
        return image;
    }

    public void setImage(@Nullable CID image) {
        this.image = image;
    }

    public boolean areItemsTheSame(@NonNull Thread thread) {
        checkNotNull(thread);
        return idx == thread.getIdx();

    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Thread thread = (Thread) o;
        return getIdx() == thread.getIdx();
    }

    @Override
    public int hashCode() {

        return Objects.hash(getIdx());
    }

    @Nullable
    public CID getCid() {
        return cid;
    }

    void setCid(@Nullable CID cid) {
        this.cid = cid;
    }

    @NonNull
    public String getSenderAlias() {
        return senderAlias;
    }

    public void setSenderAlias(@NonNull String senderAlias) {
        checkNotNull(senderAlias);
        this.senderAlias = senderAlias;
    }

    public boolean getMarkedFlag() {
        return markedFlag;
    }

    public void setMarkedFlag(boolean markedFlag) {
        this.markedFlag = markedFlag;
    }

    public int getUnreadNotes() {
        return unreadNotes;
    }

    public void setUnreadNotes(int unreadNotes) {
        this.unreadNotes = unreadNotes;
    }

    public long getThread() {
        return thread;
    }

    @NonNull
    public String getSesKey() {
        return sesKey;
    }

    public void increaseUnreadMessagesNumber() {
        unreadNotes++;
    }

    @NonNull
    public Date getDate() {
        return date;
    }

    @Deprecated
    boolean isReadOnly() {
        return readOnly;
    }

    @Deprecated
    void setReadOnly(boolean readOnly) {
        this.readOnly = readOnly;
    }

    public boolean isEncrypted() {
        return !sesKey.isEmpty();
    }

}
